@@ -8,8 +8,7 @@ from trytond.pyson import Eval
 __all__ = ['Sale', 'SaleLine']
 
 
-class Sale:
-    __metaclass__ = PoolMeta
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
 
     @classmethod
@@ -21,10 +20,11 @@ class Sale:
             field.depends.extend(['shipment_address'])
 
 
-class SaleLine:
-    __metaclass__ = PoolMeta
+class SaleLine(metaclass=PoolMeta):
     __name__ = 'sale.line'
 
+    @fields.depends('sale', '_parent_sale.warehouse',
+        '_parent_sale.shipment_address')
     def _get_tax_rule_pattern(self):
         pool = Pool()
         Location = pool.get('stock.location')
@@ -46,7 +46,3 @@ class SaleLine:
         pattern['from_country'] = from_country.id if from_country else None
         pattern['to_country'] = to_country.id if to_country else None
         return pattern
-
-    @fields.depends('_parent_sale.warehouse', '_parent_sale.shipment_address')
-    def on_change_product(self):
-        super(SaleLine, self).on_change_product()
